@@ -9,7 +9,6 @@ import voluptuous as vol
 from homeassistant.components.notify import (
     ATTR_DATA,
     ATTR_TARGET,
-    DOMAIN,
     PLATFORM_SCHEMA,
     BaseNotificationService,
 )
@@ -18,13 +17,14 @@ from homeassistant.const import ATTR_NAME, CONF_NAME, CONF_PLATFORM
 from homeassistant.helpers import template as template_helper
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.event import track_state_change
+from homeassistant.components.device_tracker import DOMAIN as DEVICE_TRACKER_DOMAIN
+
+from .const import DOMAIN
 
 APNS_DEVICES = "apns.yaml"
 CONF_CERTFILE = "cert_file"
 CONF_TOPIC = "topic"
 CONF_SANDBOX = "sandbox"
-DEVICE_TRACKER_DOMAIN = "device_tracker"
-SERVICE_REGISTER = "apns_register"
 
 ATTR_PUSH_ID = "push_id"
 
