@@ -30,7 +30,7 @@ TRIGGER_SCHEMA = vol.All(
 )
 
 
-async def async_trigger(hass, config, action, automation_info):
+async def async_attach_trigger(hass, config, action, automation_info):
     """Listen for state changes based on configuration."""
     hours = config.get(CONF_HOURS)
     minutes = config.get(CONF_MINUTES)
