@@ -36,7 +36,7 @@ async def _handle_webhook(action, hass, webhook_id, request):
     hass.async_run_job(action, {"trigger": result})
 
 
-async def async_trigger(hass, config, action, automation_info):
+async def async_attach_trigger(hass, config, action, automation_info):
     """Trigger based on incoming webhooks."""
     webhook_id = config.get(CONF_WEBHOOK_ID)
     hass.components.webhook.async_register(
