@@ -6,7 +6,6 @@ import voluptuous as vol
 from homeassistant.const import CONF_ICON, CONF_NAME, CONF_MAXIMUM, CONF_MINIMUM
 
 import homeassistant.helpers.config_validation as cv
-from homeassistant.helpers.config_validation import ENTITY_SERVICE_SCHEMA
 from homeassistant.helpers.entity_component import EntityComponent
 from homeassistant.helpers.restore_state import RestoreEntity
 
@@ -33,15 +32,6 @@ SERVICE_INCREMENT = "increment"
 SERVICE_RESET = "reset"
 SERVICE_CONFIGURE = "configure"
 
-SERVICE_SCHEMA_CONFIGURE = ENTITY_SERVICE_SCHEMA.extend(
-    {
-        vol.Optional(ATTR_MINIMUM): vol.Any(None, vol.Coerce(int)),
-        vol.Optional(ATTR_MAXIMUM): vol.Any(None, vol.Coerce(int)),
-        vol.Optional(ATTR_STEP): cv.positive_int,
-        vol.Optional(ATTR_INITIAL): cv.positive_int,
-        vol.Optional(VALUE): cv.positive_int,
-    }
-)
 
 CONFIG_SCHEMA = vol.Schema(
     {
@@ -95,17 +85,19 @@ async def async_setup(hass, config):
     if not entities:
         return False
 
+    component.async_register_entity_service(SERVICE_INCREMENT, {}, "async_increment")
+    component.async_register_entity_service(SERVICE_DECREMENT, {}, "async_decrement")
+    component.async_register_entity_service(SERVICE_RESET, {}, "async_reset")
     component.async_register_entity_service(
-        SERVICE_INCREMENT, ENTITY_SERVICE_SCHEMA, "async_increment"
-    )
-    component.async_register_entity_service(
-        SERVICE_DECREMENT, ENTITY_SERVICE_SCHEMA, "async_decrement"
-    )
-    component.async_register_entity_service(
-        SERVICE_RESET, ENTITY_SERVICE_SCHEMA, "async_reset"
-    )
-    component.async_register_entity_service(
-        SERVICE_CONFIGURE, SERVICE_SCHEMA_CONFIGURE, "async_configure"
+        SERVICE_CONFIGURE,
+        {
+            vol.Optional(ATTR_MINIMUM): vol.Any(None, vol.Coerce(int)),
+            vol.Optional(ATTR_MAXIMUM): vol.Any(None, vol.Coerce(int)),
+            vol.Optional(ATTR_STEP): cv.positive_int,
+            vol.Optional(ATTR_INITIAL): cv.positive_int,
+            vol.Optional(VALUE): cv.positive_int,
+        },
+        "async_configure",
     )
 
     await component.async_add_entities(entities)
