@@ -3,43 +3,51 @@ import asyncio
 import logging
 import time
 
-from homeassistant import bootstrap
+from homeassistant import bootstrap, config_entries
 import homeassistant.core as ha
 from homeassistant.const import ATTR_ENTITY_ID, EVENT_HOMEASSISTANT_START
 
 DOMAIN = "demo"
 _LOGGER = logging.getLogger(__name__)
-COMPONENTS_WITH_DEMO_PLATFORM = [
+
+COMPONENTS_WITH_CONFIG_ENTRY_DEMO_PLATFORM = [
     "air_quality",
     "alarm_control_panel",
     "binary_sensor",
-    "calendar",
     "camera",
     "climate",
     "cover",
-    "device_tracker",
     "fan",
-    "image_processing",
     "light",
     "lock",
     "media_player",
-    "notify",
     "sensor",
-    "stt",
     "switch",
-    "tts",
-    "mailbox",
     "water_heater",
 ]
 
+COMPONENTS_WITH_DEMO_PLATFORM = [
+    "tts",
+    "stt",
+    "mailbox",
+    "notify",
+    "image_processing",
+    "calendar",
+    "device_tracker",
+]
+
 
 async def async_setup(hass, config):
     """Set up the demo environment."""
     if DOMAIN not in config:
         return True
 
-    config.setdefault(ha.DOMAIN, {})
-    config.setdefault(DOMAIN, {})
+    if not hass.config_entries.async_entries(DOMAIN):
+        hass.async_create_task(
+            hass.config_entries.flow.async_init(
+                DOMAIN, context={"source": config_entries.SOURCE_IMPORT}, data={}
+            )
+        )
 
     # Set up demo platforms
     for component in COMPONENTS_WITH_DEMO_PLATFORM:
@@ -47,6 +55,9 @@ async def async_setup(hass, config):
             hass.helpers.discovery.async_load_platform(component, DOMAIN, {}, config)
         )
 
+    config.setdefault(ha.DOMAIN, {})
+    config.setdefault(DOMAIN, {})
+
     # Set up sun
     if not hass.config.latitude:
         hass.config.latitude = 32.87336
@@ -176,6 +187,16 @@ async def async_setup(hass, config):
     return True
 
 
+async def async_setup_entry(hass, config_entry):
+    """Set the config entry up."""
+    # Set up demo platforms with config entry
+    for component in COMPONENTS_WITH_CONFIG_ENTRY_DEMO_PLATFORM:
+        hass.async_create_task(
+            hass.config_entries.async_forward_entry_setup(config_entry, component)
+        )
+    return True
+
+
 async def finish_setup(hass, config):
     """Finish set up once demo platforms are set up."""
     switches = None
