@@ -6,31 +6,63 @@ from homeassistant.const import (
     DEVICE_CLASS_TEMPERATURE,
 )
 from homeassistant.helpers.entity import Entity
+from . import DOMAIN
 
 
-def setup_platform(hass, config, add_entities, discovery_info=None):
+async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
     """Set up the Demo sensors."""
-    add_entities(
+    async_add_entities(
         [
             DemoSensor(
-                "Outside Temperature", 15.6, DEVICE_CLASS_TEMPERATURE, TEMP_CELSIUS, 12
+                "sensor_1",
+                "Outside Temperature",
+                15.6,
+                DEVICE_CLASS_TEMPERATURE,
+                TEMP_CELSIUS,
+                12,
+            ),
+            DemoSensor(
+                "sensor_2", "Outside Humidity", 54, DEVICE_CLASS_HUMIDITY, "%", None
             ),
-            DemoSensor("Outside Humidity", 54, DEVICE_CLASS_HUMIDITY, "%", None),
         ]
     )
 
 
+async def async_setup_entry(hass, config_entry, async_add_entities):
+    """Set up the Demo config entry."""
+    await async_setup_platform(hass, {}, async_add_entities)
+
+
 class DemoSensor(Entity):
     """Representation of a Demo sensor."""
 
-    def __init__(self, name, state, device_class, unit_of_measurement, battery):
+    def __init__(
+        self, unique_id, name, state, device_class, unit_of_measurement, battery
+    ):
         """Initialize the sensor."""
+        self._unique_id = unique_id
         self._name = name
         self._state = state
         self._device_class = device_class
         self._unit_of_measurement = unit_of_measurement
         self._battery = battery
 
+    @property
+    def device_info(self):
+        """Return device info."""
+        return {
+            "identifiers": {
+                # Serial numbers are unique identifiers within a specific domain
+                (DOMAIN, self.unique_id)
+            },
+            "name": self.name,
+        }
+
+    @property
+    def unique_id(self):
+        """Return the unique id."""
+        return self._unique_id
+
     @property
     def should_poll(self):
         """No polling needed for a demo sensor."""
