@@ -9,6 +9,12 @@ https://home-assistant.io/components/sensor.eddystone_temperature/
 """
 import logging
 
+# pylint: disable=import-error
+from beacontools import (
+    BeaconScanner,
+    EddystoneFilter,
+    EddystoneTLMFrame,
+)
 import voluptuous as vol
 
 from homeassistant.components.sensor import PLATFORM_SCHEMA
@@ -150,12 +156,6 @@ class Monitor:
                 packet.temperature,
             )
 
-        from beacontools import (  # pylint: disable=import-error
-            BeaconScanner,
-            EddystoneFilter,
-            EddystoneTLMFrame,
-        )
-
         device_filters = [EddystoneFilter(d.namespace, d.instance) for d in devices]
 
         self.scanner = BeaconScanner(
