@@ -1,4 +1,4 @@
-"""Support for local control of entities by emulating a Phillips Hue bridge."""
+"""Support for local control of entities by emulating a Philips Hue bridge."""
 import logging
 
 from aiohttp import web
