@@ -60,6 +60,12 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
     """Set up Fritz!Box call monitor sensor platform."""
     name = config.get(CONF_NAME)
     host = config.get(CONF_HOST)
+    # Try to resolve a hostname; if it is already an IP, it will be returned as-is
+    try:
+        host = socket.gethostbyname(host)
+    except socket.error:
+        _LOGGER.error("Could not resolve hostname %s", host)
+        return
     port = config.get(CONF_PORT)
     username = config.get(CONF_USERNAME)
     password = config.get(CONF_PASSWORD)
