@@ -1,8 +1,10 @@
 """Support for HomematicIP Cloud devices."""
 import logging
 from pathlib import Path
+from typing import Optional
 
 from homematicip.aio.group import AsyncHeatingGroup
+from homematicip.aio.home import AsyncHome
 from homematicip.base.helpers import handle_config
 import voluptuous as vol
 
@@ -135,7 +137,7 @@ async def async_setup(hass: HomeAssistantType, config: ConfigType) -> bool:
                 )
             )
 
-    async def _async_activate_eco_mode_with_duration(service):
+    async def _async_activate_eco_mode_with_duration(service) -> None:
         """Service to activate eco mode with duration."""
         duration = service.data[ATTR_DURATION]
         hapid = service.data.get(ATTR_ACCESSPOINT_ID)
@@ -155,7 +157,7 @@ async def async_setup(hass: HomeAssistantType, config: ConfigType) -> bool:
         schema=SCHEMA_ACTIVATE_ECO_MODE_WITH_DURATION,
     )
 
-    async def _async_activate_eco_mode_with_period(service):
+    async def _async_activate_eco_mode_with_period(service) -> None:
         """Service to activate eco mode with period."""
         endtime = service.data[ATTR_ENDTIME]
         hapid = service.data.get(ATTR_ACCESSPOINT_ID)
@@ -175,7 +177,7 @@ async def async_setup(hass: HomeAssistantType, config: ConfigType) -> bool:
         schema=SCHEMA_ACTIVATE_ECO_MODE_WITH_PERIOD,
     )
 
-    async def _async_activate_vacation(service):
+    async def _async_activate_vacation(service) -> None:
         """Service to activate vacation."""
         endtime = service.data[ATTR_ENDTIME]
         temperature = service.data[ATTR_TEMPERATURE]
@@ -196,7 +198,7 @@ async def async_setup(hass: HomeAssistantType, config: ConfigType) -> bool:
         schema=SCHEMA_ACTIVATE_VACATION,
     )
 
-    async def _async_deactivate_eco_mode(service):
+    async def _async_deactivate_eco_mode(service) -> None:
         """Service to deactivate eco mode."""
         hapid = service.data.get(ATTR_ACCESSPOINT_ID)
 
@@ -215,7 +217,7 @@ async def async_setup(hass: HomeAssistantType, config: ConfigType) -> bool:
         schema=SCHEMA_DEACTIVATE_ECO_MODE,
     )
 
-    async def _async_deactivate_vacation(service):
+    async def _async_deactivate_vacation(service) -> None:
         """Service to deactivate vacation."""
         hapid = service.data.get(ATTR_ACCESSPOINT_ID)
 
@@ -234,7 +236,7 @@ async def async_setup(hass: HomeAssistantType, config: ConfigType) -> bool:
         schema=SCHEMA_DEACTIVATE_VACATION,
     )
 
-    async def _set_active_climate_profile(service):
+    async def _set_active_climate_profile(service) -> None:
         """Service to set the active climate profile."""
         entity_id_list = service.data[ATTR_ENTITY_ID]
         climate_profile_index = service.data[ATTR_CLIMATE_PROFILE_INDEX] - 1
@@ -257,7 +259,7 @@ async def async_setup(hass: HomeAssistantType, config: ConfigType) -> bool:
         schema=SCHEMA_SET_ACTIVE_CLIMATE_PROFILE,
     )
 
-    async def _async_dump_hap_config(service):
+    async def _async_dump_hap_config(service) -> None:
         """Service to dump the configuration of a Homematic IP Access Point."""
         config_path = (
             service.data.get(ATTR_CONFIG_OUTPUT_PATH) or hass.config.config_dir
@@ -287,7 +289,7 @@ async def async_setup(hass: HomeAssistantType, config: ConfigType) -> bool:
         schema=SCHEMA_DUMP_HAP_CONFIG,
     )
 
-    def _get_home(hapid: str):
+    def _get_home(hapid: str) -> Optional[AsyncHome]:
         """Return a HmIP home."""
         hap = hass.data[DOMAIN].get(hapid)
         if hap:
@@ -324,7 +326,7 @@ async def async_setup_entry(hass: HomeAssistantType, entry: ConfigEntry) -> bool
     return True
 
 
-async def async_unload_entry(hass, entry):
+async def async_unload_entry(hass: HomeAssistantType, entry: ConfigEntry) -> bool:
     """Unload a config entry."""
     hap = hass.data[DOMAIN].pop(entry.data[HMIPC_HAPID])
     return await hap.async_reset()
