@@ -16,9 +16,12 @@ KEY_DEVICE_BASIC_INFORMATION = "device_basic_information"
 KEY_DEVICE_INFORMATION = "device_information"
 KEY_DEVICE_SIGNAL = "device_signal"
 KEY_DIALUP_MOBILE_DATASWITCH = "dialup_mobile_dataswitch"
+KEY_MONITORING_STATUS = "monitoring_status"
 KEY_MONITORING_TRAFFIC_STATISTICS = "monitoring_traffic_statistics"
 KEY_WLAN_HOST_LIST = "wlan_host_list"
 
+BINARY_SENSOR_KEYS = {KEY_MONITORING_STATUS}
+
 DEVICE_TRACKER_KEYS = {KEY_WLAN_HOST_LIST}
 
 SENSOR_KEYS = {
@@ -29,4 +32,4 @@ SENSOR_KEYS = {
 
 SWITCH_KEYS = {KEY_DIALUP_MOBILE_DATASWITCH}
 
-ALL_KEYS = DEVICE_TRACKER_KEYS | SENSOR_KEYS | SWITCH_KEYS
+ALL_KEYS = BINARY_SENSOR_KEYS | DEVICE_TRACKER_KEYS | SENSOR_KEYS | SWITCH_KEYS
