@@ -2,10 +2,15 @@
 import logging
 import re
 
+from pyialarm import IAlarm
 import voluptuous as vol
 
 import homeassistant.components.alarm_control_panel as alarm
 from homeassistant.components.alarm_control_panel import PLATFORM_SCHEMA
+from homeassistant.components.alarm_control_panel.const import (
+    SUPPORT_ALARM_ARM_AWAY,
+    SUPPORT_ALARM_ARM_HOME,
+)
 from homeassistant.const import (
     CONF_CODE,
     CONF_HOST,
@@ -62,7 +67,6 @@ class IAlarmPanel(alarm.AlarmControlPanel):
 
     def __init__(self, name, code, username, password, url):
         """Initialize the iAlarm status."""
-        from pyialarm import IAlarm
 
         self._name = name
         self._code = str(code) if code else None
@@ -91,6 +95,11 @@ class IAlarmPanel(alarm.AlarmControlPanel):
         """Return the state of the device."""
         return self._state
 
+    @property
+    def supported_features(self) -> int:
+        """Return the list of supported features."""
+        return SUPPORT_ALARM_ARM_HOME | SUPPORT_ALARM_ARM_AWAY
+
     def update(self):
         """Return the state of the device."""
         status = self._client.get_status()
