@@ -20,8 +20,7 @@ SENSOR_TYPES = {
     "data": {
         "date": ["Date", "mdi:judaism"],
         "weekly_portion": ["Parshat Hashavua", "mdi:book-open-variant"],
-        "holiday_name": ["Holiday name", "mdi:calendar-star"],
-        "holiday_type": ["Holiday type", "mdi:counter"],
+        "holiday": ["Holiday", "mdi:calendar-star"],
         "omer_count": ["Day of the Omer", "mdi:counter"],
     },
     "time": {
