@@ -1,5 +1,6 @@
 """Support for KNX/IP sensors."""
 import voluptuous as vol
+from xknx.devices import Sensor as XknxSensor
 
 from homeassistant.components.sensor import PLATFORM_SCHEMA
 from homeassistant.const import CONF_NAME, CONF_TYPE
@@ -44,9 +45,7 @@ def async_add_entities_discovery(hass, discovery_info, async_add_entities):
 @callback
 def async_add_entities_config(hass, config, async_add_entities):
     """Set up sensor for KNX platform configured within platform."""
-    import xknx
-
-    sensor = xknx.devices.Sensor(
+    sensor = XknxSensor(
         hass.data[DATA_KNX].xknx,
         name=config[CONF_NAME],
         group_address_state=config[CONF_STATE_ADDRESS],
