@@ -11,10 +11,11 @@ _LOGGER = logging.getLogger(__name__)
 def setup_platform(hass, config, add_entities, discovery_info=None):
     """Set up the Lutron scenes."""
     devs = []
-    for scene_data in hass.data[LUTRON_DEVICES]['scene']:
+    for scene_data in hass.data[LUTRON_DEVICES]["scene"]:
         (area_name, keypad_name, device, led) = scene_data
-        dev = LutronScene(area_name, keypad_name, device, led,
-                          hass.data[LUTRON_CONTROLLER])
+        dev = LutronScene(
+            area_name, keypad_name, device, led, hass.data[LUTRON_CONTROLLER]
+        )
         devs.append(dev)
 
     add_entities(devs, True)
@@ -23,9 +24,7 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
 class LutronScene(LutronDevice, Scene):
     """Representation of a Lutron Scene."""
 
-    def __init__(
-            self, area_name, keypad_name, lutron_device, lutron_led,
-            controller):
+    def __init__(self, area_name, keypad_name, lutron_device, lutron_led, controller):
         """Initialize the scene/button."""
         super().__init__(area_name, lutron_device, controller)
         self._keypad_name = keypad_name
@@ -39,4 +38,5 @@ class LutronScene(LutronDevice, Scene):
     def name(self):
         """Return the name of the device."""
         return "{} {}: {}".format(
-            self._area_name, self._keypad_name, self._lutron_device.name)
+            self._area_name, self._keypad_name, self._lutron_device.name
+        )
