@@ -2,6 +2,7 @@
 from datetime import datetime, timedelta
 import logging
 
+from py_noaa import coops  # pylint: disable=import-error
 import voluptuous as vol
 
 from homeassistant.components.sensor import PLATFORM_SCHEMA
@@ -101,15 +102,14 @@ class NOAATidesAndCurrentsSensor(Entity):
         api_time = self.data.index[0]
         if self.data["hi_lo"][0] == "H":
             tidetime = api_time.strftime("%-I:%M %p")
-            return "High tide at {}".format(tidetime)
+            return f"High tide at {tidetime}"
         if self.data["hi_lo"][0] == "L":
             tidetime = api_time.strftime("%-I:%M %p")
-            return "Low tide at {}".format(tidetime)
+            return f"Low tide at {tidetime}"
         return None
 
     def update(self):
         """Get the latest data from NOAA Tides and Currents API."""
-        from py_noaa import coops  # pylint: disable=import-error
 
         begin = datetime.now()
         delta = timedelta(days=2)
