@@ -124,7 +124,7 @@ async def async_setup(hass, config):
                 p_config.get(CONF_NAME) or discovery_info.get(CONF_NAME) or p_type
             )
             for name, target in notify_service.targets.items():
-                target_name = slugify("{}_{}".format(platform_name, name))
+                target_name = slugify(f"{platform_name}_{name}")
                 targets[target_name] = target
                 hass.services.async_register(
                     DOMAIN,
@@ -145,7 +145,7 @@ async def async_setup(hass, config):
             schema=NOTIFY_SERVICE_SCHEMA,
         )
 
-        hass.config.components.add("{}.{}".format(DOMAIN, p_type))
+        hass.config.components.add(f"{DOMAIN}.{p_type}")
 
         return True
 
