@@ -1,4 +1,5 @@
 """Support for OpenTherm Gateway devices."""
+import asyncio
 import logging
 from datetime import datetime, date
 
@@ -344,6 +345,18 @@ def register_services(hass):
     )
 
 
+async def async_unload_entry(hass, entry):
+    """Cleanup and disconnect from gateway."""
+    await asyncio.gather(
+        hass.config_entries.async_forward_entry_unload(entry, COMP_BINARY_SENSOR),
+        hass.config_entries.async_forward_entry_unload(entry, COMP_CLIMATE),
+        hass.config_entries.async_forward_entry_unload(entry, COMP_SENSOR),
+    )
+    gateway = hass.data[DATA_OPENTHERM_GW][DATA_GATEWAYS][entry.data[CONF_ID]]
+    await gateway.cleanup()
+    return True
+
+
 class OpenThermGatewayDevice:
     """OpenTherm Gateway device class."""
 
@@ -358,18 +371,21 @@ class OpenThermGatewayDevice:
         self.update_signal = f"{DATA_OPENTHERM_GW}_{self.gw_id}_update"
         self.options_update_signal = f"{DATA_OPENTHERM_GW}_{self.gw_id}_options_update"
         self.gateway = pyotgw.pyotgw()
+        self.gw_version = None
+
+    async def cleanup(self, event=None):
+        """Reset overrides on the gateway."""
+        await self.gateway.set_control_setpoint(0)
+        await self.gateway.set_max_relative_mod("-")
+        await self.gateway.disconnect()
 
     async def connect_and_subscribe(self):
         """Connect to serial device and subscribe report handler."""
-        await self.gateway.connect(self.hass.loop, self.device_path)
+        self.status = await self.gateway.connect(self.hass.loop, self.device_path)
         _LOGGER.debug("Connected to OpenTherm Gateway at %s", self.device_path)
+        self.gw_version = self.status.get(gw_vars.OTGW_BUILD)
 
-        async def cleanup(event):
-            """Reset overrides on the gateway."""
-            await self.gateway.set_control_setpoint(0)
-            await self.gateway.set_max_relative_mod("-")
-
-        self.hass.bus.async_listen(EVENT_HOMEASSISTANT_STOP, cleanup)
+        self.hass.bus.async_listen(EVENT_HOMEASSISTANT_STOP, self.cleanup)
 
         async def handle_report(status):
             """Handle reports from the OpenTherm Gateway."""
