@@ -1,5 +1,6 @@
 """Support to embed Plex."""
 import asyncio
+import functools
 import logging
 
 import plexapi.exceptions
@@ -36,6 +37,7 @@ from .const import (
     DISPATCHERS,
     DOMAIN as PLEX_DOMAIN,
     PLATFORMS,
+    PLATFORMS_COMPLETED,
     PLEX_MEDIA_PLAYER_OPTIONS,
     PLEX_SERVER_CONFIG,
     PLEX_UPDATE_PLATFORMS_SIGNAL,
@@ -71,18 +73,21 @@ CONFIG_SCHEMA = vol.Schema({PLEX_DOMAIN: SERVER_CONFIG_SCHEMA}, extra=vol.ALLOW_
 _LOGGER = logging.getLogger(__package__)
 
 
-def setup(hass, config):
+async def async_setup(hass, config):
     """Set up the Plex component."""
-    hass.data.setdefault(PLEX_DOMAIN, {SERVERS: {}, DISPATCHERS: {}, WEBSOCKETS: {}})
+    hass.data.setdefault(
+        PLEX_DOMAIN,
+        {SERVERS: {}, DISPATCHERS: {}, WEBSOCKETS: {}, PLATFORMS_COMPLETED: {}},
+    )
 
     plex_config = config.get(PLEX_DOMAIN, {})
     if plex_config:
-        _setup_plex(hass, plex_config)
+        _async_setup_plex(hass, plex_config)
 
     return True
 
 
-def _setup_plex(hass, config):
+def _async_setup_plex(hass, config):
     """Pass configuration to a config flow."""
     server_config = dict(config)
     if MP_DOMAIN in server_config:
@@ -140,11 +145,7 @@ async def async_setup_entry(hass, entry):
     )
     server_id = plex_server.machine_identifier
     hass.data[PLEX_DOMAIN][SERVERS][server_id] = plex_server
-
-    for platform in PLATFORMS:
-        hass.async_create_task(
-            hass.config_entries.async_forward_entry_setup(entry, platform)
-        )
+    hass.data[PLEX_DOMAIN][PLATFORMS_COMPLETED][server_id] = set()
 
     entry.add_update_listener(async_options_updated)
 
@@ -160,10 +161,17 @@ async def async_setup_entry(hass, entry):
         async_dispatcher_send(hass, PLEX_UPDATE_PLATFORMS_SIGNAL.format(server_id))
 
     session = async_get_clientsession(hass)
-    websocket = PlexWebsocket(plex_server.plex_server, update_plex, session)
-    hass.loop.create_task(websocket.listen())
+    verify_ssl = server_config.get(CONF_VERIFY_SSL)
+    websocket = PlexWebsocket(
+        plex_server.plex_server, update_plex, session=session, verify_ssl=verify_ssl
+    )
     hass.data[PLEX_DOMAIN][WEBSOCKETS][server_id] = websocket
 
+    def start_websocket_session(platform, _):
+        hass.data[PLEX_DOMAIN][PLATFORMS_COMPLETED][server_id].add(platform)
+        if hass.data[PLEX_DOMAIN][PLATFORMS_COMPLETED][server_id] == PLATFORMS:
+            hass.loop.create_task(websocket.listen())
+
     def close_websocket_session(_):
         websocket.close()
 
@@ -172,6 +180,12 @@ async def async_setup_entry(hass, entry):
     )
     hass.data[PLEX_DOMAIN][DISPATCHERS][server_id].append(unsub)
 
+    for platform in PLATFORMS:
+        task = hass.async_create_task(
+            hass.config_entries.async_forward_entry_setup(entry, platform)
+        )
+        task.add_done_callback(functools.partial(start_websocket_session, platform))
+
     return True
 
 
