@@ -4,16 +4,16 @@ import logging
 
 LOGGER = logging.getLogger(__package__)
 
-DOMAIN = 'rainmachine'
+DOMAIN = "rainmachine"
 
-DATA_CLIENT = 'client'
+DATA_CLIENT = "client"
 
 DEFAULT_PORT = 8080
 DEFAULT_SCAN_INTERVAL = timedelta(seconds=60)
 DEFAULT_SSL = True
 
-PROVISION_SETTINGS = 'provision.settings'
-RESTRICTIONS_CURRENT = 'restrictions.current'
-RESTRICTIONS_UNIVERSAL = 'restrictions.universal'
+PROVISION_SETTINGS = "provision.settings"
+RESTRICTIONS_CURRENT = "restrictions.current"
+RESTRICTIONS_UNIVERSAL = "restrictions.universal"
 
-TOPIC_UPDATE = 'update_{0}'
+TOPIC_UPDATE = "update_{0}"
