@@ -1,12 +1,18 @@
 """Support for interface with an Samsung TV."""
 import asyncio
 from datetime import timedelta
-import logging
 import socket
 
+from samsungctl import exceptions as samsung_exceptions, Remote as SamsungRemote
 import voluptuous as vol
+import wakeonlan
+from websocket import WebSocketException
 
-from homeassistant.components.media_player import MediaPlayerDevice, PLATFORM_SCHEMA
+from homeassistant.components.media_player import (
+    MediaPlayerDevice,
+    PLATFORM_SCHEMA,
+    DEVICE_CLASS_TV,
+)
 from homeassistant.components.media_player.const import (
     MEDIA_TYPE_CHANNEL,
     SUPPORT_NEXT_TRACK,
@@ -21,6 +27,7 @@ from homeassistant.components.media_player.const import (
     SUPPORT_VOLUME_STEP,
 )
 from homeassistant.const import (
+    CONF_BROADCAST_ADDRESS,
     CONF_HOST,
     CONF_MAC,
     CONF_NAME,
@@ -32,14 +39,15 @@ from homeassistant.const import (
 import homeassistant.helpers.config_validation as cv
 from homeassistant.util import dt as dt_util
 
-_LOGGER = logging.getLogger(__name__)
+from .const import LOGGER
 
 DEFAULT_NAME = "Samsung TV Remote"
-DEFAULT_PORT = 55000
 DEFAULT_TIMEOUT = 1
+DEFAULT_BROADCAST_ADDRESS = "255.255.255.255"
 
 KEY_PRESS_TIMEOUT = 1.2
 KNOWN_DEVICES_KEY = "samsungtv_known_devices"
+METHODS = ("websocket", "legacy")
 SOURCES = {"TV": "KEY_TV", "HDMI": "KEY_HDMI"}
 
 SUPPORT_SAMSUNGTV = (
@@ -58,8 +66,11 @@ PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
     {
         vol.Required(CONF_HOST): cv.string,
         vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
-        vol.Optional(CONF_PORT, default=DEFAULT_PORT): cv.port,
+        vol.Optional(CONF_PORT): cv.port,
         vol.Optional(CONF_MAC): cv.string,
+        vol.Optional(
+            CONF_BROADCAST_ADDRESS, default=DEFAULT_BROADCAST_ADDRESS
+        ): cv.string,
         vol.Optional(CONF_TIMEOUT, default=DEFAULT_TIMEOUT): cv.positive_int,
     }
 )
@@ -79,49 +90,45 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
         port = config.get(CONF_PORT)
         name = config.get(CONF_NAME)
         mac = config.get(CONF_MAC)
+        broadcast = config.get(CONF_BROADCAST_ADDRESS)
         timeout = config.get(CONF_TIMEOUT)
     elif discovery_info is not None:
         tv_name = discovery_info.get("name")
         model = discovery_info.get("model_name")
         host = discovery_info.get("host")
         name = f"{tv_name} ({model})"
-        port = DEFAULT_PORT
+        if name.startswith("[TV]"):
+            name = name[4:]
+        port = None
         timeout = DEFAULT_TIMEOUT
         mac = None
-        udn = discovery_info.get("udn")
-        if udn and udn.startswith("uuid:"):
-            uuid = udn[len("uuid:") :]
-    else:
-        _LOGGER.warning("Cannot determine device")
-        return
+        broadcast = DEFAULT_BROADCAST_ADDRESS
+        uuid = discovery_info.get("udn")
+        if uuid and uuid.startswith("uuid:"):
+            uuid = uuid[len("uuid:") :]
 
     # Only add a device once, so discovered devices do not override manual
     # config.
     ip_addr = socket.gethostbyname(host)
     if ip_addr not in known_devices:
         known_devices.add(ip_addr)
-        add_entities([SamsungTVDevice(host, port, name, timeout, mac, uuid)])
-        _LOGGER.info("Samsung TV %s:%d added as '%s'", host, port, name)
+        add_entities([SamsungTVDevice(host, port, name, timeout, mac, broadcast, uuid)])
+        LOGGER.info("Samsung TV %s added as '%s'", host, name)
     else:
-        _LOGGER.info("Ignoring duplicate Samsung TV %s:%d", host, port)
+        LOGGER.info("Ignoring duplicate Samsung TV %s", host)
 
 
 class SamsungTVDevice(MediaPlayerDevice):
     """Representation of a Samsung TV."""
 
-    def __init__(self, host, port, name, timeout, mac, uuid):
+    def __init__(self, host, port, name, timeout, mac, broadcast, uuid):
         """Initialize the Samsung device."""
-        from samsungctl import exceptions
-        from samsungctl import Remote
-        import wakeonlan
 
         # Save a reference to the imported classes
-        self._exceptions_class = exceptions
-        self._remote_class = Remote
         self._name = name
         self._mac = mac
+        self._broadcast = broadcast
         self._uuid = uuid
-        self._wol = wakeonlan
         # Assume that the TV is not muted
         self._muted = False
         # Assume that the TV is in Play mode
@@ -136,14 +143,16 @@ class SamsungTVDevice(MediaPlayerDevice):
             "name": "HomeAssistant",
             "description": name,
             "id": "ha.component.samsung",
+            "method": None,
             "port": port,
             "host": host,
             "timeout": timeout,
         }
 
+        # Select method by port number, mainly for fallback
         if self._config["port"] in (8001, 8002):
             self._config["method"] = "websocket"
-        else:
+        elif self._config["port"] == 55000:
             self._config["method"] = "legacy"
 
     def update(self):
@@ -152,16 +161,47 @@ class SamsungTVDevice(MediaPlayerDevice):
 
     def get_remote(self):
         """Create or return a remote control instance."""
+
+        # Try to find correct method automatically
+        if self._config["method"] not in METHODS:
+            for method in METHODS:
+                try:
+                    self._config["method"] = method
+                    LOGGER.debug("Try config: %s", self._config)
+                    self._remote = SamsungRemote(self._config.copy())
+                    self._state = STATE_ON
+                    LOGGER.debug("Found working config: %s", self._config)
+                    break
+                except (
+                    samsung_exceptions.UnhandledResponse,
+                    samsung_exceptions.AccessDenied,
+                ):
+                    # We got a response so it's working.
+                    self._state = STATE_ON
+                    LOGGER.debug(
+                        "Found working config without connection: %s", self._config
+                    )
+                    break
+                except OSError as err:
+                    LOGGER.debug("Failing config: %s error was: %s", self._config, err)
+                    self._config["method"] = None
+
+            # Unable to find working connection
+            if self._config["method"] is None:
+                self._remote = None
+                self._state = None
+                return None
+
         if self._remote is None:
             # We need to create a new instance to reconnect.
-            self._remote = self._remote_class(self._config)
+            self._remote = SamsungRemote(self._config.copy())
 
         return self._remote
 
     def send_key(self, key):
         """Send a key to the tv and handles exceptions."""
         if self._power_off_in_progress() and key not in ("KEY_POWER", "KEY_POWEROFF"):
-            _LOGGER.info("TV is powering off, not sending command: %s", key)
+            LOGGER.info("TV is powering off, not sending command: %s", key)
             return
         try:
             # recreate connection if connection was dead
@@ -170,20 +210,26 @@ class SamsungTVDevice(MediaPlayerDevice):
                 try:
                     self.get_remote().control(key)
                     break
-                except (self._exceptions_class.ConnectionClosed, BrokenPipeError):
+                except (
+                    samsung_exceptions.ConnectionClosed,
+                    BrokenPipeError,
+                    WebSocketException,
+                ):
                     # BrokenPipe can occur when the commands is sent to fast
+                    # WebSocketException can occur when timed out
                     self._remote = None
             self._state = STATE_ON
-        except (
-            self._exceptions_class.UnhandledResponse,
-            self._exceptions_class.AccessDenied,
-        ):
+        except AttributeError:
+            # Auto-detect could not find working config yet
+            pass
+        except (samsung_exceptions.UnhandledResponse, samsung_exceptions.AccessDenied):
             # We got a response so it's on.
             self._state = STATE_ON
             self._remote = None
-            _LOGGER.debug("Failed sending command %s", key, exc_info=True)
+            LOGGER.debug("Failed sending command %s", key, exc_info=True)
             return
         except OSError:
+            # Different reasons, e.g. hostname not resolveable
             self._state = STATE_OFF
             self._remote = None
         if self._power_off_in_progress():
@@ -227,6 +273,11 @@ class SamsungTVDevice(MediaPlayerDevice):
             return SUPPORT_SAMSUNGTV | SUPPORT_TURN_ON
         return SUPPORT_SAMSUNGTV
 
+    @property
+    def device_class(self):
+        """Set the device class to TV."""
+        return DEVICE_CLASS_TV
+
     def turn_off(self):
         """Turn off media player."""
         self._end_of_power_off = dt_util.utcnow() + timedelta(seconds=15)
@@ -240,7 +291,7 @@ class SamsungTVDevice(MediaPlayerDevice):
             self.get_remote().close()
             self._remote = None
         except OSError:
-            _LOGGER.debug("Could not establish connection.")
+            LOGGER.debug("Could not establish connection.")
 
     def volume_up(self):
         """Volume up the media player."""
@@ -273,23 +324,23 @@ class SamsungTVDevice(MediaPlayerDevice):
 
     def media_next_track(self):
         """Send next track command."""
-        self.send_key("KEY_FF")
+        self.send_key("KEY_CHUP")
 
     def media_previous_track(self):
         """Send the previous track command."""
-        self.send_key("KEY_REWIND")
+        self.send_key("KEY_CHDOWN")
 
     async def async_play_media(self, media_type, media_id, **kwargs):
         """Support changing a channel."""
         if media_type != MEDIA_TYPE_CHANNEL:
-            _LOGGER.error("Unsupported media type")
+            LOGGER.error("Unsupported media type")
             return
 
         # media_id should only be a channel number
         try:
             cv.positive_int(media_id)
         except vol.Invalid:
-            _LOGGER.error("Media ID must be positive integer")
+            LOGGER.error("Media ID must be positive integer")
             return
 
         for digit in media_id:
@@ -300,14 +351,14 @@ class SamsungTVDevice(MediaPlayerDevice):
     def turn_on(self):
         """Turn the media player on."""
         if self._mac:
-            self._wol.send_magic_packet(self._mac)
+            wakeonlan.send_magic_packet(self._mac, ip_address=self._broadcast)
         else:
             self.send_key("KEY_POWERON")
 
     async def async_select_source(self, source):
         """Select input source."""
         if source not in SOURCES:
-            _LOGGER.error("Unsupported source")
+            LOGGER.error("Unsupported source")
             return
 
         await self.hass.async_add_job(self.send_key, SOURCES[source])
