@@ -4,8 +4,7 @@ from homeassistant.components.scene import Scene
 from .const import DATA_BROKERS, DOMAIN
 
 
-async def async_setup_platform(
-        hass, config, async_add_entities, discovery_info=None):
+async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
     """Platform uses config entry setup."""
     pass
 
@@ -13,8 +12,7 @@ async def async_setup_platform(
 async def async_setup_entry(hass, config_entry, async_add_entities):
     """Add switches for a config entry."""
     broker = hass.data[DOMAIN][DATA_BROKERS][config_entry.entry_id]
-    async_add_entities(
-        [SmartThingsScene(scene) for scene in broker.scenes.values()])
+    async_add_entities([SmartThingsScene(scene) for scene in broker.scenes.values()])
 
 
 class SmartThingsScene(Scene):
@@ -32,9 +30,9 @@ class SmartThingsScene(Scene):
     def device_state_attributes(self):
         """Get attributes about the state."""
         return {
-            'icon': self._scene.icon,
-            'color': self._scene.color,
-            'location_id': self._scene.location_id
+            "icon": self._scene.icon,
+            "color": self._scene.color,
+            "location_id": self._scene.location_id,
         }
 
     @property
