@@ -3,9 +3,9 @@ import asyncio
 from datetime import timedelta
 import logging
 from urllib.parse import urlparse
-from xml.etree import ElementTree
 
 import aiohttp
+from defusedxml import ElementTree
 from netdisco import ssdp, util
 
 from homeassistant.helpers.event import async_track_time_interval
