@@ -1,22 +1,22 @@
 """Support for Tado Smart device trackers."""
-import logging
-from datetime import timedelta
-from collections import namedtuple
-
 import asyncio
+from collections import namedtuple
+from datetime import timedelta
+import logging
+
 import aiohttp
 import async_timeout
 import voluptuous as vol
 
-import homeassistant.helpers.config_validation as cv
-from homeassistant.const import CONF_USERNAME, CONF_PASSWORD
-from homeassistant.util import Throttle
 from homeassistant.components.device_tracker import (
     DOMAIN,
     PLATFORM_SCHEMA,
     DeviceScanner,
 )
+from homeassistant.const import CONF_PASSWORD, CONF_USERNAME
 from homeassistant.helpers.aiohttp_client import async_create_clientsession
+import homeassistant.helpers.config_validation as cv
+from homeassistant.util import Throttle
 
 _LOGGER = logging.getLogger(__name__)
 
