@@ -25,7 +25,6 @@ from homeassistant.const import (
     CONF_ENTITY_ID,
     STATE_ON,
     STATE_OFF,
-    MATCH_ALL,
     EVENT_HOMEASSISTANT_START,
     STATE_UNKNOWN,
 )
@@ -33,6 +32,7 @@ from homeassistant.core import callback
 from homeassistant.exceptions import TemplateError
 from homeassistant.helpers.entity import async_generate_entity_id
 from homeassistant.helpers.script import Script
+from . import extract_entities, initialise_templates
 from .const import CONF_AVAILABILITY_TEMPLATE
 
 _LOGGER = logging.getLogger(__name__)
@@ -98,33 +98,16 @@ async def async_setup_platform(hass, config, async_add_entities, discovery_info=
 
         speed_list = device_config[CONF_SPEED_LIST]
 
-        entity_ids = set()
-        manual_entity_ids = device_config.get(CONF_ENTITY_ID)
+        templates = {
+            CONF_VALUE_TEMPLATE: state_template,
+            CONF_SPEED_TEMPLATE: speed_template,
+            CONF_OSCILLATING_TEMPLATE: oscillating_template,
+            CONF_DIRECTION_TEMPLATE: direction_template,
+            CONF_AVAILABILITY_TEMPLATE: availability_template,
+        }
 
-        for template in (
-            state_template,
-            speed_template,
-            oscillating_template,
-            direction_template,
-            availability_template,
-        ):
-            if template is None:
-                continue
-            template.hass = hass
-
-            if entity_ids == MATCH_ALL or manual_entity_ids is not None:
-                continue
-
-            template_entity_ids = template.extract_entities()
-            if template_entity_ids == MATCH_ALL:
-                entity_ids = MATCH_ALL
-            else:
-                entity_ids |= set(template_entity_ids)
-
-        if manual_entity_ids is not None:
-            entity_ids = manual_entity_ids
-        elif entity_ids != MATCH_ALL:
-            entity_ids = list(entity_ids)
+        initialise_templates(hass, templates)
+        entity_ids = extract_entities(device, "fan", None, templates)
 
         fans.append(
             TemplateFan(
