@@ -2,9 +2,8 @@
 from collections import defaultdict
 import logging
 
-import voluptuous as vol
 from teslajsonpy import Controller as teslaAPI, TeslaException
-
+import voluptuous as vol
 
 from homeassistant.const import (
     ATTR_BATTERY_LEVEL,
@@ -12,18 +11,14 @@ from homeassistant.const import (
     CONF_SCAN_INTERVAL,
     CONF_USERNAME,
 )
-from homeassistant.helpers import config_validation as cv
-from homeassistant.helpers import discovery
+from homeassistant.helpers import aiohttp_client, config_validation as cv, discovery
 from homeassistant.helpers.entity import Entity
 from homeassistant.util import slugify
 
-DOMAIN = "tesla"
+from .const import DOMAIN, TESLA_COMPONENTS
 
 _LOGGER = logging.getLogger(__name__)
 
-TESLA_ID_FORMAT = "{}_{}"
-TESLA_ID_LIST_SCHEMA = vol.Schema([int])
-
 CONFIG_SCHEMA = vol.Schema(
     {
         DOMAIN: vol.Schema(
@@ -42,17 +37,8 @@ CONFIG_SCHEMA = vol.Schema(
 NOTIFICATION_ID = "tesla_integration_notification"
 NOTIFICATION_TITLE = "Tesla integration setup"
 
-TESLA_COMPONENTS = [
-    "sensor",
-    "lock",
-    "climate",
-    "binary_sensor",
-    "device_tracker",
-    "switch",
-]
 
-
-def setup(hass, base_config):
+async def async_setup(hass, base_config):
     """Set up of Tesla component."""
     config = base_config.get(DOMAIN)
 
@@ -61,10 +47,15 @@ def setup(hass, base_config):
     update_interval = config.get(CONF_SCAN_INTERVAL)
     if hass.data.get(DOMAIN) is None:
         try:
-            hass.data[DOMAIN] = {
-                "controller": teslaAPI(email, password, update_interval),
-                "devices": defaultdict(list),
-            }
+            websession = aiohttp_client.async_get_clientsession(hass)
+            controller = teslaAPI(
+                websession,
+                email=email,
+                password=password,
+                update_interval=update_interval,
+            )
+            await controller.connect(test_login=False)
+            hass.data[DOMAIN] = {"controller": controller, "devices": defaultdict(list)}
             _LOGGER.debug("Connected to the Tesla API.")
         except TeslaException as ex:
             if ex.code == 401:
@@ -85,9 +76,7 @@ def setup(hass, base_config):
                 )
             _LOGGER.error("Unable to communicate with Tesla API: %s", ex.message)
             return False
-
-    all_devices = hass.data[DOMAIN]["controller"].list_vehicles()
-
+    all_devices = controller.get_homeassistant_components()
     if not all_devices:
         return False
 
@@ -95,8 +84,9 @@ def setup(hass, base_config):
         hass.data[DOMAIN]["devices"][device.hass_type].append(device)
 
     for component in TESLA_COMPONENTS:
-        discovery.load_platform(hass, component, DOMAIN, {}, base_config)
-
+        hass.async_create_task(
+            discovery.async_load_platform(hass, component, DOMAIN, {}, base_config)
+        )
     return True
 
 
@@ -104,11 +94,12 @@ class TeslaDevice(Entity):
     """Representation of a Tesla device."""
 
     def __init__(self, tesla_device, controller):
-        """Initialise of the Tesla device."""
+        """Initialise the Tesla device."""
         self.tesla_device = tesla_device
         self.controller = controller
         self._name = self.tesla_device.name
         self.tesla_id = slugify(self.tesla_device.uniq_name)
+        self._attributes = {}
 
     @property
     def name(self):
@@ -128,8 +119,19 @@ class TeslaDevice(Entity):
     @property
     def device_state_attributes(self):
         """Return the state attributes of the device."""
-        attr = {}
-
+        attr = self._attributes
         if self.tesla_device.has_battery():
             attr[ATTR_BATTERY_LEVEL] = self.tesla_device.battery_level()
         return attr
+
+    async def async_added_to_hass(self):
+        """Register state update callback."""
+        pass
+
+    async def async_will_remove_from_hass(self):
+        """Prepare for unload."""
+        pass
+
+    async def async_update(self):
+        """Update the state of the device."""
+        await self.tesla_device.async_update()
