@@ -9,7 +9,7 @@ from . import DOMAIN as TESLA_DOMAIN, TeslaDevice
 _LOGGER = logging.getLogger(__name__)
 
 
-def setup_platform(hass, config, add_entities, discovery_info=None):
+async def async_setup_platform(hass, config, add_entities, discovery_info=None):
     """Set up the Tesla lock platform."""
     devices = [
         TeslaLock(device, hass.data[TESLA_DOMAIN]["controller"])
@@ -26,23 +26,23 @@ class TeslaLock(TeslaDevice, LockDevice):
         self._state = None
         super().__init__(tesla_device, controller)
 
-    def lock(self, **kwargs):
+    async def async_lock(self, **kwargs):
         """Send the lock command."""
         _LOGGER.debug("Locking doors for: %s", self._name)
-        self.tesla_device.lock()
+        await self.tesla_device.lock()
 
-    def unlock(self, **kwargs):
+    async def async_unlock(self, **kwargs):
         """Send the unlock command."""
         _LOGGER.debug("Unlocking doors for: %s", self._name)
-        self.tesla_device.unlock()
+        await self.tesla_device.unlock()
 
     @property
     def is_locked(self):
         """Get whether the lock is in locked state."""
         return self._state == STATE_LOCKED
 
-    def update(self):
+    async def async_update(self):
         """Update state of the lock."""
         _LOGGER.debug("Updating state for: %s", self._name)
-        self.tesla_device.update()
+        await super().async_update()
         self._state = STATE_LOCKED if self.tesla_device.is_locked() else STATE_UNLOCKED
