@@ -19,7 +19,6 @@ from homeassistant.exceptions import ConfigEntryNotReady
 from homeassistant.helpers import config_validation as cv
 from homeassistant.helpers.dispatcher import dispatcher_send
 from homeassistant.helpers.event import async_track_time_interval
-from homeassistant.util import slugify
 
 from .const import (
     ATTR_TORRENT,
@@ -28,13 +27,16 @@ from .const import (
     DEFAULT_SCAN_INTERVAL,
     DOMAIN,
     SERVICE_ADD_TORRENT,
+    DATA_UPDATED,
 )
 from .errors import AuthenticationError, CannotConnect, UnknownError
 
 _LOGGER = logging.getLogger(__name__)
 
 
-SERVICE_ADD_TORRENT_SCHEMA = vol.Schema({vol.Required(ATTR_TORRENT): cv.string})
+SERVICE_ADD_TORRENT_SCHEMA = vol.Schema(
+    {vol.Required(ATTR_TORRENT): cv.string, vol.Required(CONF_NAME): cv.string}
+)
 
 TRANS_SCHEMA = vol.All(
     vol.Schema(
@@ -55,6 +57,8 @@ CONFIG_SCHEMA = vol.Schema(
     {DOMAIN: vol.All(cv.ensure_list, [TRANS_SCHEMA])}, extra=vol.ALLOW_EXTRA
 )
 
+PLATFORMS = ["sensor", "switch"]
+
 
 async def async_setup(hass, config):
     """Import the Transmission Component from config."""
@@ -82,15 +86,15 @@ async def async_setup_entry(hass, config_entry):
 
 async def async_unload_entry(hass, config_entry):
     """Unload Transmission Entry from config_entry."""
-    client = hass.data[DOMAIN][config_entry.entry_id]
-    hass.services.async_remove(DOMAIN, client.service_name)
+    client = hass.data[DOMAIN].pop(config_entry.entry_id)
     if client.unsub_timer:
         client.unsub_timer()
 
-    for component in "sensor", "switch":
-        await hass.config_entries.async_forward_entry_unload(config_entry, component)
+    for platform in PLATFORMS:
+        await hass.config_entries.async_forward_entry_unload(config_entry, platform)
 
-    hass.data[DOMAIN].pop(config_entry.entry_id)
+    if not hass.data[DOMAIN]:
+        hass.services.async_remove(DOMAIN, SERVICE_ADD_TORRENT)
 
     return True
 
@@ -128,14 +132,10 @@ class TransmissionClient:
         """Initialize the Transmission RPC API."""
         self.hass = hass
         self.config_entry = config_entry
+        self.tm_api = None
         self._tm_data = None
         self.unsub_timer = None
 
-    @property
-    def service_name(self):
-        """Return the service name."""
-        return slugify(f"{SERVICE_ADD_TORRENT}_{self.config_entry.data[CONF_NAME]}")
-
     @property
     def api(self):
         """Return the tm_data object."""
@@ -145,20 +145,20 @@ class TransmissionClient:
         """Set up the Transmission client."""
 
         try:
-            api = await get_api(self.hass, self.config_entry.data)
+            self.tm_api = await get_api(self.hass, self.config_entry.data)
         except CannotConnect:
             raise ConfigEntryNotReady
         except (AuthenticationError, UnknownError):
             return False
 
-        self._tm_data = TransmissionData(self.hass, self.config_entry, api)
+        self._tm_data = TransmissionData(self.hass, self.config_entry, self.tm_api)
 
         await self.hass.async_add_executor_job(self._tm_data.init_torrent_list)
         await self.hass.async_add_executor_job(self._tm_data.update)
         self.add_options()
         self.set_scan_interval(self.config_entry.options[CONF_SCAN_INTERVAL])
 
-        for platform in ["sensor", "switch"]:
+        for platform in PLATFORMS:
             self.hass.async_create_task(
                 self.hass.config_entries.async_forward_entry_setup(
                     self.config_entry, platform
@@ -167,18 +167,26 @@ class TransmissionClient:
 
         def add_torrent(service):
             """Add new torrent to download."""
+            tm_client = None
+            for entry in self.hass.config_entries.async_entries(DOMAIN):
+                if entry.data[CONF_NAME] == service.data[CONF_NAME]:
+                    tm_client = self.hass.data[DOMAIN][entry.entry_id]
+                    break
+            if tm_client is None:
+                _LOGGER.error("Transmission instance is not found")
+                return
             torrent = service.data[ATTR_TORRENT]
             if torrent.startswith(
                 ("http", "ftp:", "magnet:")
             ) or self.hass.config.is_allowed_path(torrent):
-                api.add_torrent(torrent)
+                tm_client.tm_api.add_torrent(torrent)
             else:
                 _LOGGER.warning(
                     "Could not add torrent: unsupported type or no permission"
                 )
 
         self.hass.services.async_register(
-            DOMAIN, self.service_name, add_torrent, schema=SERVICE_ADD_TORRENT_SCHEMA
+            DOMAIN, SERVICE_ADD_TORRENT, add_torrent, schema=SERVICE_ADD_TORRENT_SCHEMA
         )
 
         self.config_entry.add_update_listener(self.async_options_updated)
@@ -200,7 +208,7 @@ class TransmissionClient:
     def set_scan_interval(self, scan_interval):
         """Update scan interval."""
 
-        async def refresh(event_time):
+        def refresh(event_time):
             """Get the latest data from Transmission."""
             self._tm_data.update()
 
@@ -240,9 +248,9 @@ class TransmissionData:
         return self.config.data[CONF_HOST]
 
     @property
-    def signal_options_update(self):
-        """Option update signal per transmission entry."""
-        return f"tm-options-{self.host}"
+    def signal_update(self):
+        """Update signal per transmission entry."""
+        return f"{DATA_UPDATED}-{self.host}"
 
     def update(self):
         """Get the latest data from Transmission instance."""
@@ -260,7 +268,7 @@ class TransmissionData:
         except TransmissionError:
             self.available = False
             _LOGGER.error("Unable to connect to Transmission client %s", self.host)
-        dispatcher_send(self.hass, self.signal_options_update)
+        dispatcher_send(self.hass, self.signal_update)
 
     def init_torrent_list(self):
         """Initialize torrent lists."""
