@@ -40,6 +40,7 @@ class TransmissionSwitch(ToggleEntity):
         self._tm_client = tm_client
         self._state = STATE_OFF
         self._data = None
+        self.unsub_update = None
 
     @property
     def name(self):
@@ -93,9 +94,9 @@ class TransmissionSwitch(ToggleEntity):
 
     async def async_added_to_hass(self):
         """Handle entity which will be added."""
-        async_dispatcher_connect(
+        self.unsub_update = async_dispatcher_connect(
             self.hass,
-            self._tm_client.api.signal_options_update,
+            self._tm_client.api.signal_update,
             self._schedule_immediate_update,
         )
 
@@ -103,6 +104,12 @@ class TransmissionSwitch(ToggleEntity):
     def _schedule_immediate_update(self):
         self.async_schedule_update_ha_state(True)
 
+    async def will_remove_from_hass(self):
+        """Unsubscribe from update dispatcher."""
+        if self.unsub_update:
+            self.unsub_update()
+            self.unsub_update = None
+
     def update(self):
         """Get the latest data from Transmission and updates the state."""
         active = None
