@@ -6,8 +6,9 @@ import voluptuous as vol
 from homeassistant.components.switch import PLATFORM_SCHEMA, SwitchDevice
 from homeassistant.const import STATE_OFF
 import homeassistant.helpers.config_validation as cv
+from homeassistant.helpers.dispatcher import dispatcher_send
 
-from . import CONF_SERVERS, DATA_UPCLOUD, UpCloudServerEntity
+from . import CONF_SERVERS, DATA_UPCLOUD, SIGNAL_UPDATE_UPCLOUD, UpCloudServerEntity
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -34,6 +35,7 @@ class UpCloudSwitch(UpCloudServerEntity, SwitchDevice):
         """Start the server."""
         if self.state == STATE_OFF:
             self.data.start()
+            dispatcher_send(self.hass, SIGNAL_UPDATE_UPCLOUD)
 
     def turn_off(self, **kwargs):
         """Stop the server."""
