@@ -98,6 +98,11 @@ class VenstarThermostat(ClimateDevice):
         """Initialize the thermostat."""
         self._client = client
         self._humidifier = humidifier
+        self._mode_map = {
+            HVAC_MODE_HEAT: self._client.MODE_HEAT,
+            HVAC_MODE_COOL: self._client.MODE_COOL,
+            HVAC_MODE_AUTO: self._client.MODE_AUTO,
+        }
 
     def update(self):
         """Update the data from the thermostat."""
@@ -242,6 +247,7 @@ class VenstarThermostat(ClimateDevice):
             return PRESET_AWAY
         if self._client.schedule == 0:
             return HOLD_MODE_TEMPERATURE
+        return PRESET_NONE
 
     @property
     def preset_modes(self):
@@ -266,20 +272,29 @@ class VenstarThermostat(ClimateDevice):
     def set_temperature(self, **kwargs):
         """Set a new target temperature."""
         set_temp = True
-        operation_mode = kwargs.get(ATTR_HVAC_MODE, self._client.mode)
+        operation_mode = kwargs.get(ATTR_HVAC_MODE)
         temp_low = kwargs.get(ATTR_TARGET_TEMP_LOW)
         temp_high = kwargs.get(ATTR_TARGET_TEMP_HIGH)
         temperature = kwargs.get(ATTR_TEMPERATURE)
 
-        if operation_mode != self._client.mode:
+        if operation_mode and self._mode_map.get(operation_mode) != self._client.mode:
             set_temp = self._set_operation_mode(operation_mode)
 
         if set_temp:
-            if operation_mode == self._client.MODE_HEAT:
+            if (
+                self._mode_map.get(operation_mode, self._client.mode)
+                == self._client.MODE_HEAT
+            ):
                 success = self._client.set_setpoints(temperature, self._client.cooltemp)
-            elif operation_mode == self._client.MODE_COOL:
+            elif (
+                self._mode_map.get(operation_mode, self._client.mode)
+                == self._client.MODE_COOL
+            ):
                 success = self._client.set_setpoints(self._client.heattemp, temperature)
-            elif operation_mode == self._client.MODE_AUTO:
+            elif (
+                self._mode_map.get(operation_mode, self._client.mode)
+                == self._client.MODE_AUTO
+            ):
                 success = self._client.set_setpoints(temp_low, temp_high)
             else:
                 success = False
@@ -318,13 +333,11 @@ class VenstarThermostat(ClimateDevice):
         if preset_mode == PRESET_AWAY:
             success = self._client.set_away(self._client.AWAY_AWAY)
         elif preset_mode == HOLD_MODE_TEMPERATURE:
-            success = self._client.set_schedule(0)
+            success = self._client.set_away(self._client.AWAY_HOME)
+            success = success and self._client.set_schedule(0)
         elif preset_mode == PRESET_NONE:
-            success = False
-            if self._client.away:
-                success = self._client.set_away(self._client.AWAY_HOME)
-            if self._client.schedule == 0:
-                success = success and self._client.set_schedule(1)
+            success = self._client.set_away(self._client.AWAY_HOME)
+            success = success and self._client.set_schedule(1)
         else:
             _LOGGER.error("Unknown hold mode: %s", preset_mode)
             success = False
