@@ -2,34 +2,35 @@
 import logging
 
 from homeassistant.components.binary_sensor import (
+    DEVICE_CLASS_GAS,
+    DEVICE_CLASS_MOISTURE,
+    DEVICE_CLASS_MOTION,
+    DEVICE_CLASS_MOVING,
+    DEVICE_CLASS_OCCUPANCY,
+    DEVICE_CLASS_OPENING,
+    DEVICE_CLASS_SMOKE,
+    DEVICE_CLASS_VIBRATION,
     DOMAIN,
     BinarySensorDevice,
-    DEVICE_CLASS_MOVING,
-    DEVICE_CLASS_MOTION,
-    DEVICE_CLASS_OPENING,
-    DEVICE_CLASS_MOISTURE,
-    DEVICE_CLASS_SMOKE,
-    DEVICE_CLASS_GAS,
-    DEVICE_CLASS_VIBRATION,
-    DEVICE_CLASS_OCCUPANCY,
 )
 from homeassistant.const import STATE_ON
 from homeassistant.core import callback
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
+
 from .core.const import (
+    CHANNEL_ATTRIBUTE,
+    CHANNEL_ON_OFF,
+    CHANNEL_ZONE,
     DATA_ZHA,
     DATA_ZHA_DISPATCHERS,
-    ZHA_DISCOVERY_NEW,
-    ON_OFF_CHANNEL,
-    ZONE_CHANNEL,
-    SIGNAL_ATTR_UPDATED,
-    ATTRIBUTE_CHANNEL,
-    UNKNOWN,
-    OPENING,
-    ZONE,
-    OCCUPANCY,
+    SENSOR_ACCELERATION,
+    SENSOR_OCCUPANCY,
+    SENSOR_OPENING,
     SENSOR_TYPE,
-    ACCELERATION,
+    SIGNAL_ATTR_UPDATED,
+    UNKNOWN,
+    ZHA_DISCOVERY_NEW,
+    ZONE,
 )
 from .entity import ZhaEntity
 
@@ -54,10 +55,10 @@ async def get_ias_device_class(channel):
 
 DEVICE_CLASS_REGISTRY = {
     UNKNOWN: None,
-    OPENING: DEVICE_CLASS_OPENING,
+    SENSOR_OPENING: DEVICE_CLASS_OPENING,
     ZONE: get_ias_device_class,
-    OCCUPANCY: DEVICE_CLASS_OCCUPANCY,
-    ACCELERATION: DEVICE_CLASS_MOVING,
+    SENSOR_OCCUPANCY: DEVICE_CLASS_OCCUPANCY,
+    SENSOR_ACCELERATION: DEVICE_CLASS_MOVING,
 }
 
 
@@ -108,9 +109,9 @@ class BinarySensor(ZhaEntity, BinarySensorDevice):
         """Initialize the ZHA binary sensor."""
         super().__init__(**kwargs)
         self._device_state_attributes = {}
-        self._zone_channel = self.cluster_channels.get(ZONE_CHANNEL)
-        self._on_off_channel = self.cluster_channels.get(ON_OFF_CHANNEL)
-        self._attr_channel = self.cluster_channels.get(ATTRIBUTE_CHANNEL)
+        self._zone_channel = self.cluster_channels.get(CHANNEL_ZONE)
+        self._on_off_channel = self.cluster_channels.get(CHANNEL_ON_OFF)
+        self._attr_channel = self.cluster_channels.get(CHANNEL_ATTRIBUTE)
         self._zha_sensor_type = kwargs[SENSOR_TYPE]
 
     async def _determine_device_class(self):
