@@ -34,6 +34,11 @@ ATTR_RSSI = "rssi"
 ATTR_SIGNATURE = "signature"
 ATTR_TYPE = "type"
 ATTR_VALUE = "value"
+ATTR_WARNING_DEVICE_DURATION = "duration"
+ATTR_WARNING_DEVICE_MODE = "mode"
+ATTR_WARNING_DEVICE_STROBE = "strobe"
+ATTR_WARNING_DEVICE_STROBE_DUTY_CYCLE = "duty_cycle"
+ATTR_WARNING_DEVICE_STROBE_INTENSITY = "intensity"
 
 BAUD_RATES = [2400, 4800, 9600, 14400, 19200, 38400, 57600, 115200, 128000, 256000]
 
@@ -44,6 +49,7 @@ CHANNEL_DOORLOCK = "door_lock"
 CHANNEL_ELECTRICAL_MEASUREMENT = "electrical_measurement"
 CHANNEL_EVENT_RELAY = "event_relay"
 CHANNEL_FAN = "fan"
+CHANNEL_IAS_WD = "ias_wd"
 CHANNEL_LEVEL = ATTR_LEVEL
 CHANNEL_ON_OFF = "on_off"
 CHANNEL_POWER_CONFIGURATION = "power"
@@ -177,6 +183,30 @@ UNKNOWN = "unknown"
 UNKNOWN_MANUFACTURER = "unk_manufacturer"
 UNKNOWN_MODEL = "unk_model"
 
+WARNING_DEVICE_MODE_STOP = 0
+WARNING_DEVICE_MODE_BURGLAR = 1
+WARNING_DEVICE_MODE_FIRE = 2
+WARNING_DEVICE_MODE_EMERGENCY = 3
+WARNING_DEVICE_MODE_POLICE_PANIC = 4
+WARNING_DEVICE_MODE_FIRE_PANIC = 5
+WARNING_DEVICE_MODE_EMERGENCY_PANIC = 6
+
+WARNING_DEVICE_STROBE_NO = 0
+WARNING_DEVICE_STROBE_YES = 1
+
+WARNING_DEVICE_SOUND_LOW = 0
+WARNING_DEVICE_SOUND_MEDIUM = 1
+WARNING_DEVICE_SOUND_HIGH = 2
+WARNING_DEVICE_SOUND_VERY_HIGH = 3
+
+WARNING_DEVICE_STROBE_LOW = 0x00
+WARNING_DEVICE_STROBE_MEDIUM = 0x01
+WARNING_DEVICE_STROBE_HIGH = 0x02
+WARNING_DEVICE_STROBE_VERY_HIGH = 0x03
+
+WARNING_DEVICE_SQUAWK_MODE_ARMED = 0
+WARNING_DEVICE_SQUAWK_MODE_DISARMED = 1
+
 ZHA_DISCOVERY_NEW = "zha_discovery_new_{}"
 ZHA_GW_MSG_RAW_INIT = "raw_device_initialized"
 ZHA_GW_MSG = "zha_gateway_message"
