@@ -35,7 +35,7 @@ from homeassistant.helpers.dispatcher import (
 )
 
 from . import const
-from . import config_flow  # noqa pylint: disable=unused-import
+from . import config_flow  # noqa: F401 pylint: disable=unused-import
 from . import websocket_api as wsapi
 from .const import (
     CONF_AUTOHEAL,
