@@ -69,6 +69,7 @@ DATA_CUSTOMIZE = "hass_customize"
 GROUP_CONFIG_PATH = "groups.yaml"
 AUTOMATION_CONFIG_PATH = "automations.yaml"
 SCRIPT_CONFIG_PATH = "scripts.yaml"
+SCENE_CONFIG_PATH = "scenes.yaml"
 
 DEFAULT_CONFIG = f"""
 # Configure a default setup of Home Assistant (frontend, api, etc)
@@ -85,6 +86,7 @@ tts:
 group: !include {GROUP_CONFIG_PATH}
 automation: !include {AUTOMATION_CONFIG_PATH}
 script: !include {SCRIPT_CONFIG_PATH}
+scene: !include {SCENE_CONFIG_PATH}
 """
 DEFAULT_SECRETS = """
 # Use this file to store secrets like usernames and passwords.
@@ -261,6 +263,7 @@ def _write_default_config(config_dir: str) -> Optional[str]:
     group_yaml_path = os.path.join(config_dir, GROUP_CONFIG_PATH)
     automation_yaml_path = os.path.join(config_dir, AUTOMATION_CONFIG_PATH)
     script_yaml_path = os.path.join(config_dir, SCRIPT_CONFIG_PATH)
+    scene_yaml_path = os.path.join(config_dir, SCENE_CONFIG_PATH)
 
     # Writing files with YAML does not create the most human readable results
     # So we're hard coding a YAML template.
@@ -283,6 +286,9 @@ def _write_default_config(config_dir: str) -> Optional[str]:
         with open(script_yaml_path, "wt"):
             pass
 
+        with open(scene_yaml_path, "wt"):
+            pass
+
         return config_path
 
     except OSError:
@@ -450,9 +456,10 @@ def _format_config_error(ex: Exception, domain: str, config: Dict) -> str:
     )
 
     if domain != CONF_CORE:
+        integration = domain.split(".")[-1]
         message += (
             "Please check the docs at "
-            "https://home-assistant.io/integrations/{}/".format(domain)
+            f"https://home-assistant.io/integrations/{integration}/"
         )
 
     return message
@@ -620,7 +627,6 @@ async def merge_packages_config(
     _log_pkg_error: Callable = _log_pkg_error,
 ) -> Dict:
     """Merge packages into the top-level configuration. Mutate config."""
-    # pylint: disable=too-many-nested-blocks
     PACKAGES_CONFIG_SCHEMA(packages)
     for pack_name, pack_conf in packages.items():
         for comp_name, comp_conf in pack_conf.items():
@@ -759,7 +765,6 @@ async def async_process_component_config(
 
         # Validate platform specific schema
         if hasattr(platform, "PLATFORM_SCHEMA"):
-            # pylint: disable=no-member
             try:
                 p_validated = platform.PLATFORM_SCHEMA(  # type: ignore
                     p_config
