@@ -18,3 +18,14 @@ def icon_for_battery_level(
     elif 5 < battery_level < 95:
         icon += "-{}".format(int(round(battery_level / 10 - 0.01)) * 10)
     return icon
+
+
+def icon_for_signal_level(signal_level: Optional[int] = None) -> str:
+    """Return a signal icon valid identifier."""
+    if signal_level is None or signal_level == 0:
+        return "mdi:signal-cellular-outline"
+    if signal_level > 70:
+        return "mdi:signal-cellular-3"
+    if signal_level > 30:
+        return "mdi:signal-cellular-2"
+    return "mdi:signal-cellular-1"
