@@ -1,6 +1,10 @@
 """Temperature util functions."""
 from homeassistant.const import (
-    TEMP_CELSIUS, TEMP_FAHRENHEIT, UNIT_NOT_RECOGNIZED_TEMPLATE, TEMPERATURE)
+    TEMP_CELSIUS,
+    TEMP_FAHRENHEIT,
+    UNIT_NOT_RECOGNIZED_TEMPLATE,
+    TEMPERATURE,
+)
 
 
 def fahrenheit_to_celsius(fahrenheit: float, interval: bool = False) -> float:
@@ -17,15 +21,14 @@ def celsius_to_fahrenheit(celsius: float, interval: bool = False) -> float:
     return celsius * 1.8 + 32.0
 
 
-def convert(temperature: float, from_unit: str, to_unit: str,
-            interval: bool = False) -> float:
+def convert(
+    temperature: float, from_unit: str, to_unit: str, interval: bool = False
+) -> float:
     """Convert a temperature from one unit to another."""
     if from_unit not in (TEMP_CELSIUS, TEMP_FAHRENHEIT):
-        raise ValueError(UNIT_NOT_RECOGNIZED_TEMPLATE.format(
-            from_unit, TEMPERATURE))
+        raise ValueError(UNIT_NOT_RECOGNIZED_TEMPLATE.format(from_unit, TEMPERATURE))
     if to_unit not in (TEMP_CELSIUS, TEMP_FAHRENHEIT):
-        raise ValueError(UNIT_NOT_RECOGNIZED_TEMPLATE.format(
-            to_unit, TEMPERATURE))
+        raise ValueError(UNIT_NOT_RECOGNIZED_TEMPLATE.format(to_unit, TEMPERATURE))
 
     if from_unit == to_unit:
         return temperature
