@@ -34,7 +34,7 @@ def convert(volume: float, from_unit: str, to_unit: str) -> float:
         raise ValueError(UNIT_NOT_RECOGNIZED_TEMPLATE.format(to_unit, VOLUME))
 
     if not isinstance(volume, Number):
-        raise TypeError("{} is not of numeric type".format(volume))
+        raise TypeError(f"{volume} is not of numeric type")
 
     # type ignore: https://github.com/python/mypy/issues/7207
     if from_unit == to_unit:  # type: ignore
